This module provides implementations of the order parameters for studying the formation of molecular crystals that are 
discussed in the paper by Santiso and Trout that is cited below. These order parameters work by measuring whether the coordination
environment around each individual molecule is similar to the environment found in a reference structure.    
